@@ -83,7 +83,7 @@
 
 /* master_avail_event - create child process to handle connection request */
 
-static void master_avail_event(int event, char *context)
+static void master_avail_event(int event, void *context)
 {
     MASTER_SERV *serv = (MASTER_SERV *) context;
     time_t  now;
@@ -167,7 +167,7 @@ void    master_avail_listen(MASTER_SERV *serv)
 	    msg_info("%s: enable events %s", myname, serv->name);
 	for (n = 0; n < serv->listen_fd_count; n++)
 	    event_enable_read(serv->listen_fd[n], master_avail_event,
-			      (char *) serv);
+			      (void *) serv);
 	serv->flags |= MASTER_FLAG_LISTEN;
     } else if (!listen_flag && MASTER_LISTENING(serv)) {
 	if (msg_verbose)
@@ -237,8 +237,8 @@ void    master_avail_less(MASTER_SERV *serv, MASTER_PROC *proc)
      * problems, the code below invokes no code in other master_XXX modules,
      * and modifies no data that is maintained by other master_XXX modules.
      * 
-     * This child is no longer available for servicing connection requests.
-     * When no child processes are available, start monitoring the service's
+     * This child is no longer available for servicing connection requests. When
+     * no child processes are available, start monitoring the service's
      * listen socket for new connection requests.
      */
     if (msg_verbose)
